@@ -109,6 +109,10 @@ class Settings:
         connections.append(_('BenQ/Siemens phone'))
         helps.append(_('BenQ or Siemens phone not running Symbian.'))
 
+        names.append('nota')
+        connections.append(_('Motorola phone'))
+        helps.append(_('Motorola phone not running Symbian.'))
+
         names.append('nokia')
         connections.append(_('Nokia phone'))
         helps.append(_('Nokia phone not running Symbian.'))
@@ -327,9 +331,10 @@ class Settings:
         helps = []
 
         if self.driver == 'at':
-            names.append('at')
-            connections.append(_('Generic AT over serial line or it\'s emulation'))
-            helps.append(_('Select this if you have real serial port or it is emulated by phone driver (eg. virtual COM port, /dev/rfcomm, /dev/ircomm, etc.).'))
+            if self.connection != 'bluetooth':
+                names.append('at')
+                connections.append(_('Generic AT over serial line or it\'s emulation'))
+                helps.append(_('Select this if you have real serial port or it is emulated by phone driver (eg. virtual COM port, /dev/rfcomm, /dev/ircomm, etc.).'))
 
             if self.connection == 'serial':
                 for rate in [19200, 38400, 115200]:
@@ -342,6 +347,10 @@ class Settings:
                 connections.append(_('AT over Bluetooth'))
                 helps.append(_('Select this if your phone is connected over Bluetooth and you want to use native Bluetooth connection.'))
 
+                names.append('at')
+                connections.append(_('Generic AT over serial line or it\'s emulation'))
+                helps.append(_('Select this if you have real serial port or it is emulated by phone driver (eg. virtual COM port, /dev/rfcomm, /dev/ircomm, etc.).'))
+
                 names.append('bluerfat')
                 connections.append(_('AT over Bluetooth with RF searching'))
                 helps.append(_('Use for Bluetooth stack and 6210 / DCT4 Nokia models, which don\'t inform about Bluetooth services correctly (6310, 6310i with firmware lower than 5.50, 8910,..)'))
