@@ -10,7 +10,7 @@ Config handler wrapper with various defaults, which might be platform dependant.
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2007 Michal Čihař
+Copyright © 2003 - 2008 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -82,6 +82,8 @@ DEFAULT_CONFIG = {
     '/Gammu/Section': 0,
     '/User/Name': Wammu.OSUtils.GetUserFullName(),
     '/Gammu/Gammurc': os.path.join(u'~', u'.gammurc'),
+    '/Hacks/MaxEmptyGuess': 50,
+    '/Hacks/MaxEmptyKnown': 100,
     }
 
 
