@@ -8,7 +8,7 @@ Execution script
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2007 Michal Čihař
+Copyright © 2003 - 2008 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -36,6 +36,14 @@ try:
 except ImportError:
     pass
 
+# Disable warning about missing files
+# This can be caused by attempt to import Python modules, which don't
+# have all DLLs satisfied.
+if sys.platform.startswith('win'):
+    import win32api
+    import win32con
+    win32api.SetErrorMode(win32con.SEM_NOOPENFILEERRORBOX)
+
 def version():
     '''
     Displays version information.
@@ -66,8 +74,8 @@ def parse_options():
     Processes program options.
     '''
     try:
-        opts, args = getopt.getopt(sys.argv[1:], 
-                'hvl', 
+        opts, args = getopt.getopt(sys.argv[1:],
+                'hvl',
                 ['help', 'version', 'local-locales'])
     except getopt.GetoptError, val:
         usage()
